(optional) Logical: in Linux and MacOS, if gdal_path was
not manually defined, GDAL is searched within the system path in case this
argument is left to default value FALSE; instead, if TRUE, a full search is
performed. In Windows, if the default OSGeo directory C:\\OSGeo4W64 exists,
GDAL is searched there, instead in the main directory C:\\; setting
full_scan to TRUE, is is always searched in the whole C:\\.
This argument takes no effect if gdal_path was defined, since, in that case,
a full search is always performed in gdal_path.